pathspec: Utility library for gitignore style pattern matching of file paths
============================================================================

Description
-----------

Utility library for gitignore style pattern matching of file paths

License
-------

MPL 2.0

Upstream Contact
----------------

https://pypi.org/project/pathspec/

